#
# spec file for package vkeybd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           vkeybd
Version:        0.1.18d
Release:        24.15
Summary:        Virtual Keyboard Instrument
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Midi
URL:            http://www.alsa-project.org/~iwai/alsa.html
Source:         ftp://ftp.suse.com/pub/people/tiwai/vkeybd/%{name}-%{version}.tar.bz2
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(tk)

%description
Vkeybd is a virtual keyboard (as in musical instrument) for AWE32/64,
raw MIDI, and ALSA sequencer drivers.  It is written in Tcl/Tk.  Enjoy
playing music with your "computer" keyboard.

%prep
%setup -q -n %{name}

%build
TCL_VERSION=$(echo 'puts $tcl_version' | tclsh)
make COPTFLAGS="%{optflags}" \
	PREFIX=%{_prefix} \
	TCL_VERSION=$TCL_VERSION \
	USE_LASH=0 \
	XLIB=""

%install
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install
make DESTDIR=%{buildroot} MAN_DIR=%{_mandir} install-man
make DESTDIR=%{buildroot} PREFIX=%{_prefix} install-desktop
ln -sf vkeybd_48x48.png %{buildroot}%{_datadir}/pixmaps/vkeybd.png
%suse_update_desktop_file vkeybd AudioVideo Music

%files
%{_bindir}/*
%{_datadir}/vkeybd
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.png
%{_mandir}/man*/*
%doc README ChangeLog

%changelog
* Fri Feb 19 2021 tiwai@suse.de
- Fix broken symlink of icon file that broke the TW build
* Tue Apr  3 2018 tchvatal@suse.com
- Format with spec-cleaner
- Fix rpmlint warnings
- Disable lash integration for now as we try to remove it from
  Tumbleweed
* Tue Nov 28 2017 crrodriguez@opensuse.org
- Remove xorg-x11-devel from BuildRequires and explicit linking
  to x11, not required anymore to build tk apps.
* Wed Aug 26 2009 tiwai@suse.de
- version 0.1.18d:
  Two debian fixes regarding keyboard inputs:
    http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=527942
    http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=527943
* Thu Jul 16 2009 tiwai@suse.de
- version 0.1.18c:
  * Add LASH support
* Thu Apr 17 2008 tiwai@suse.de
- version 0.1.18b:
  * improved vkeybd.desktop
- use 48x48 pixmap for the default icon
- automated tcl version detection in spec file
* Mon Apr  7 2008 ro@suse.de
- hardcode tcl version for the moment to fix build
* Mon Jan 14 2008 tiwai@suse.de
- version 0.1.18a:
  * fixed a packaging bug
- version 0.1.18:
  * select the default keymap per locale
* Mon Aug  6 2007 tiwai@suse.de
- version 0.1.17b:
  * fix build without linux/awe_voice.h
* Tue Jan 16 2007 tiwai@suse.de
- use $RPM_OPT_FLAGS.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Oct 11 2005 tiwai@suse.de
- updated to version 0.1.17a.
- removed ladcca support (temprarily)
* Wed Sep 15 2004 tiwai@suse.de
- fixed missing icon; create symlink vkeybd_32x32.png -> vkeybd.png.
* Tue Aug 31 2004 tiwai@suse.de
- updated to version 0.1.17.
* Wed Mar  3 2004 tiwai@suse.de
- updated to version 0.1.16
  desktop and icons are included in tarball.
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Nov 20 2003 tiwai@suse.de
- updated to version 0.1.15.
- added jack and e2fsprogs to neededforbuild, which are required
  by the new ladcca.
* Mon Sep 15 2003 tiwai@suse.de
- added desktop icon.
* Tue Aug 19 2003 tiwai@suse.de
- updated to version 0.1.14.
* Mon Aug 18 2003 tiwai@suse.de
- added desktop file.
* Thu Jul 24 2003 tiwai@suse.de
- added tk-devel to neededforbuild.
* Thu Jul  3 2003 tiwai@suse.de
- updated to version 0.1.13a.
- added the support of LADCCA.
* Fri Feb 28 2003 tiwai@suse.de
- removed the annoying debug messages.
* Thu Jan 23 2003 tiwai@suse.de
- updated to version 0.1.13.
* Fri Jan 17 2003 tiwai@suse.de
- added the extended rc file for the german keyboard layout.
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <xshared> to <x-devel-packages>
- changed neededforbuild <xdevel> to <>
* Fri Aug 23 2002 tiwai@suse.de
- removed (again) debug prints.
* Wed Aug 14 2002 tiwai@suse.de
- neededforbuild xf86 -> xdevel, xshared
* Thu Jul 25 2002 tiwai@suse.de
- removed debug prints.
* Fri Jul 12 2002 max@suse.de
- Detecting Tcl/Tk version at build time.
* Mon May  6 2002 tiwai@suse.de
- fixed build on 64bit architectures.
- check Tk_Main is defined.
- do not bind default keys if already defined by user.
* Thu Jan 17 2002 tiwai@suse.de
- fixed mouse motion on ebony keys.
* Mon Jan  7 2002 tiwai@suse.de
- updated to ver.0.1.11.
  key auto-repeat hack is enabled.
* Tue Jul 24 2001 tiwai@suse.de
- updated to ver.0.1.10a.
  ALSA 0.9.x API is supported.
* Fri Jul 13 2001 grimmer@suse.de
- Fixed file list (using wildcards for man pages)
* Wed Nov 29 2000 ro@suse.de
- changed neededforbuild <tcld> to <tcl-devel>
* Tue Nov 28 2000 tiwai@suse.de
- Fixed title bar on alsa device mode.
- Added a hack to avoid kernel oops on alsa device mode.
* Mon Nov 20 2000 tiwai@suse.de
- Updated to ver.0.1.9.
- Added --octave and --name options.
* Fri Nov 17 2000 tiwai@suse.de
- Fixed window title.
* Thu Nov  2 2000 tiwai@suse.de
- Fixed typo.
* Thu Nov  2 2000 tiwai@suse.de
- Fixed spec file for long package-name support.
* Fri Oct 13 2000 tiwai@suse.de
- Updated to 0.1.8
* Tue Sep 26 2000 tiwai@suse.de
- Changed to bzip2
* Tue Jul 11 2000 tiwai@suse.de
- First version: 0.1.7c
